@@ -96,7 +96,7 @@
 
 
 /* Copy the first part of user declarations.  */
-#line 23 "/Users/tamas/dev/igraph/igraph/src/io/gml-parser.y"
+
 
 
 /* 
@@ -133,15 +133,11 @@
 #include "io/gml-header.h"
 #include "io/gml-tree.h"
 #include "io/parsers/gml-parser.h"
+#include "io/parsers/gml-lexer.h"
 #include "internal/hacks.h" /* strcasecmp */
 
-#define yyscan_t void*
-
-int igraph_gml_yylex(YYSTYPE* lvalp, YYLTYPE* llocp, void *scanner);
 int igraph_gml_yyerror(YYLTYPE* locp, igraph_i_gml_parsedata_t *context, 
                        const char *s);
-char *igraph_gml_yyget_text (yyscan_t yyscanner );
-int igraph_gml_yyget_leng (yyscan_t yyscanner );
 void igraph_i_gml_get_keyword(char *s, int len, void *res);
 void igraph_i_gml_get_string(char *s, int len, void *res);
 double igraph_i_gml_get_real(char *s, int len);
@@ -179,7 +175,7 @@ igraph_gml_tree_t *igraph_i_gml_merge(igraph_gml_tree_t *t1, igraph_gml_tree_t*
 
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
 typedef union YYSTYPE
-#line 95 "/Users/tamas/dev/igraph/igraph/src/io/gml-parser.y"
+
 {
    struct {
       char *s;
@@ -189,7 +185,7 @@ typedef union YYSTYPE
    double real;
 }
 /* Line 193 of yacc.c.  */
-#line 193 "/Users/tamas/dev/igraph/igraph/build/src/io/parsers/gml-parser.c"
+
 	YYSTYPE;
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
@@ -214,7 +210,7 @@ typedef struct YYLTYPE
 
 
 /* Line 216 of yacc.c.  */
-#line 218 "/Users/tamas/dev/igraph/igraph/build/src/io/parsers/gml-parser.c"
+
 
 #ifdef short
 # undef short
@@ -502,8 +498,8 @@ static const yytype_int8 yyrhs[] =
 /* YYRLINE[YYN] -- source line where rule number YYN was defined.  */
 static const yytype_uint8 yyrline[] =
 {
-       0,   123,   123,   124,   127,   128,   130,   132,   134,   136,
-     140,   143,   146
+       0,   119,   119,   120,   123,   124,   126,   128,   130,   132,
+     136,   139,   142
 };
 #endif
 
@@ -1116,29 +1112,29 @@ yydestruct (yymsg, yytype, yyvaluep, yylocationp, context)
   switch (yytype)
     {
       case 5: /* "KEYWORD" */
-#line 118 "/Users/tamas/dev/igraph/igraph/src/io/gml-parser.y"
+
 	{ IGRAPH_FREE((yyvaluep->str).s); };
-#line 1122 "/Users/tamas/dev/igraph/igraph/build/src/io/parsers/gml-parser.c"
+
 	break;
       case 12: /* "list" */
-#line 119 "/Users/tamas/dev/igraph/igraph/src/io/gml-parser.y"
+
 	{ igraph_gml_tree_destroy((yyvaluep->tree)); };
-#line 1127 "/Users/tamas/dev/igraph/igraph/build/src/io/parsers/gml-parser.c"
+
 	break;
       case 13: /* "keyvalue" */
-#line 119 "/Users/tamas/dev/igraph/igraph/src/io/gml-parser.y"
+
 	{ igraph_gml_tree_destroy((yyvaluep->tree)); };
-#line 1132 "/Users/tamas/dev/igraph/igraph/build/src/io/parsers/gml-parser.c"
+
 	break;
       case 14: /* "key" */
-#line 118 "/Users/tamas/dev/igraph/igraph/src/io/gml-parser.y"
+
 	{ IGRAPH_FREE((yyvaluep->str).s); };
-#line 1137 "/Users/tamas/dev/igraph/igraph/build/src/io/parsers/gml-parser.c"
+
 	break;
       case 16: /* "string" */
-#line 118 "/Users/tamas/dev/igraph/igraph/src/io/gml-parser.y"
+
 	{ IGRAPH_FREE((yyvaluep->str).s); };
-#line 1142 "/Users/tamas/dev/igraph/igraph/build/src/io/parsers/gml-parser.c"
+
 	break;
 
       default:
@@ -1461,60 +1457,60 @@ yyreduce:
   switch (yyn)
     {
         case 2:
-#line 123 "/Users/tamas/dev/igraph/igraph/src/io/gml-parser.y"
+
     { context->tree=(yyvsp[(1) - (1)].tree); ;}
     break;
 
   case 3:
-#line 124 "/Users/tamas/dev/igraph/igraph/src/io/gml-parser.y"
+
     { context->tree=(yyvsp[(1) - (2)].tree); ;}
     break;
 
   case 4:
-#line 127 "/Users/tamas/dev/igraph/igraph/src/io/gml-parser.y"
+
     { (yyval.tree)=(yyvsp[(1) - (1)].tree); ;}
     break;
 
   case 5:
-#line 128 "/Users/tamas/dev/igraph/igraph/src/io/gml-parser.y"
+
     { (yyval.tree)=igraph_i_gml_merge((yyvsp[(1) - (2)].tree), (yyvsp[(2) - (2)].tree)); ;}
     break;
 
   case 6:
-#line 131 "/Users/tamas/dev/igraph/igraph/src/io/gml-parser.y"
+
     { (yyval.tree)=igraph_i_gml_make_numeric((yyvsp[(1) - (2)].str).s, (yyvsp[(1) - (2)].str).len, (yyvsp[(2) - (2)].real)); ;}
     break;
 
   case 7:
-#line 133 "/Users/tamas/dev/igraph/igraph/src/io/gml-parser.y"
+
     { (yyval.tree)=igraph_i_gml_make_string((yyvsp[(1) - (2)].str).s, (yyvsp[(1) - (2)].str).len, (yyvsp[(2) - (2)].str).s, (yyvsp[(2) - (2)].str).len); ;}
     break;
 
   case 8:
-#line 135 "/Users/tamas/dev/igraph/igraph/src/io/gml-parser.y"
+
     { (yyval.tree)=igraph_i_gml_make_list((yyvsp[(1) - (4)].str).s, (yyvsp[(1) - (4)].str).len, (yyvsp[(3) - (4)].tree)); ;}
     break;
 
   case 9:
-#line 137 "/Users/tamas/dev/igraph/igraph/src/io/gml-parser.y"
+
     { (yyval.tree)=igraph_i_gml_make_numeric2((yyvsp[(1) - (2)].str).s, (yyvsp[(1) - (2)].str).len, (yyvsp[(2) - (2)].str).s, (yyvsp[(2) - (2)].str).len); ;}
     break;
 
   case 10:
-#line 140 "/Users/tamas/dev/igraph/igraph/src/io/gml-parser.y"
+
     { igraph_i_gml_get_keyword(igraph_gml_yyget_text(scanner), 
                                         igraph_gml_yyget_leng(scanner), 
                                         &(yyval.str)); USE((yyvsp[(1) - (1)].str)); ;}
     break;
 
   case 11:
-#line 143 "/Users/tamas/dev/igraph/igraph/src/io/gml-parser.y"
+
     { (yyval.real)=igraph_i_gml_get_real(igraph_gml_yyget_text(scanner), 
                                      igraph_gml_yyget_leng(scanner)); ;}
     break;
 
   case 12:
-#line 146 "/Users/tamas/dev/igraph/igraph/src/io/gml-parser.y"
+
     { igraph_i_gml_get_string(igraph_gml_yyget_text(scanner), 
                                          igraph_gml_yyget_leng(scanner), 
                                          &(yyval.str)); ;}
@@ -1522,7 +1518,7 @@ yyreduce:
 
 
 /* Line 1267 of yacc.c.  */
-#line 1526 "/Users/tamas/dev/igraph/igraph/build/src/io/parsers/gml-parser.c"
+
       default: break;
     }
   YY_SYMBOL_PRINT ("-> $$ =", yyr1[yyn], &yyval, &yyloc);
@@ -1742,7 +1738,7 @@ yyreturn:
 }
 
 
-#line 150 "/Users/tamas/dev/igraph/igraph/src/io/gml-parser.y"
+
 
 
 int igraph_gml_yyerror(YYLTYPE* locp, igraph_i_gml_parsedata_t *context, 
