@@ -90,7 +90,7 @@
 
 
 /* Copy the first part of user declarations.  */
-#line 23 "/Users/tamas/dev/igraph/igraph/src/io/lgl-parser.y"
+
 
 
 /* 
@@ -119,23 +119,18 @@
 #include <string.h>
 
 #include "igraph_types.h" 
-#include "core/math.h"
 #include "igraph_memory.h"
 #include "igraph_error.h"
 #include "config.h"
 
+#include "core/math.h"
 #include "io/lgl-header.h"
 #include "io/parsers/lgl-parser.h"
+#include "io/parsers/lgl-lexer.h"
 #include "internal/hacks.h"
 
-#define yyscan_t void*
-
-int igraph_lgl_yylex(YYSTYPE* lvalp, YYLTYPE* llocp, 
-		     void* scanner);
 int igraph_lgl_yyerror(YYLTYPE* locp, igraph_i_lgl_parsedata_t *context, 
 		       const char *s);
-char *igraph_lgl_yyget_text (yyscan_t yyscanner );
-int igraph_lgl_yyget_leng (yyscan_t yyscanner );
 igraph_real_t igraph_lgl_get_number(const char *str, long int len);
 
 #define scanner context->scanner
@@ -161,13 +156,13 @@ igraph_real_t igraph_lgl_get_number(const char *str, long int len);
 
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
 typedef union YYSTYPE
-#line 83 "/Users/tamas/dev/igraph/igraph/src/io/lgl-parser.y"
+
 {
   long int edgenum;
   double weightnum;
 }
 /* Line 193 of yacc.c.  */
-#line 171 "/Users/tamas/dev/igraph/igraph/build/src/io/parsers/lgl-parser.c"
+
 	YYSTYPE;
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
@@ -192,7 +187,7 @@ typedef struct YYLTYPE
 
 
 /* Line 216 of yacc.c.  */
-#line 196 "/Users/tamas/dev/igraph/igraph/build/src/io/parsers/lgl-parser.c"
+
 
 #ifdef short
 # undef short
@@ -480,8 +475,8 @@ static const yytype_int8 yyrhs[] =
 /* YYRLINE[YYN] -- source line where rule number YYN was defined.  */
 static const yytype_uint8 yyrline[] =
 {
-       0,    98,    98,    99,   100,   103,   105,   107,   107,   109,
-     114,   123,   128
+       0,    93,    93,    94,    95,    98,   100,   102,   102,   104,
+     109,   118,   123
 };
 #endif
 
@@ -1414,12 +1409,12 @@ yyreduce:
   switch (yyn)
     {
         case 6:
-#line 105 "/Users/tamas/dev/igraph/igraph/src/io/lgl-parser.y"
+
     { context->actvertex=(yyvsp[(2) - (3)].edgenum); ;}
     break;
 
   case 9:
-#line 109 "/Users/tamas/dev/igraph/igraph/src/io/lgl-parser.y"
+
     { 
              igraph_vector_push_back(context->vector, context->actvertex);
              igraph_vector_push_back(context->vector, (yyvsp[(1) - (2)].edgenum));
@@ -1428,7 +1423,7 @@ yyreduce:
     break;
 
   case 10:
-#line 114 "/Users/tamas/dev/igraph/igraph/src/io/lgl-parser.y"
+
     { 
 	     igraph_vector_push_back(context->vector, context->actvertex);
              igraph_vector_push_back(context->vector, (yyvsp[(1) - (3)].edgenum));
@@ -1438,7 +1433,7 @@ yyreduce:
     break;
 
   case 11:
-#line 123 "/Users/tamas/dev/igraph/igraph/src/io/lgl-parser.y"
+
     { igraph_trie_get2(context->trie, 
 				   igraph_lgl_yyget_text(scanner), 
 				   igraph_lgl_yyget_leng(scanner), 
@@ -1446,14 +1441,14 @@ yyreduce:
     break;
 
   case 12:
-#line 128 "/Users/tamas/dev/igraph/igraph/src/io/lgl-parser.y"
+
     { (yyval.weightnum)=igraph_lgl_get_number(igraph_lgl_yyget_text(scanner), 
 					   igraph_lgl_yyget_leng(scanner)); ;}
     break;
 
 
 /* Line 1267 of yacc.c.  */
-#line 1457 "/Users/tamas/dev/igraph/igraph/build/src/io/parsers/lgl-parser.c"
+
       default: break;
     }
   YY_SYMBOL_PRINT ("-> $$ =", yyr1[yyn], &yyval, &yyloc);
@@ -1673,7 +1668,7 @@ yyreturn:
 }
 
 
-#line 131 "/Users/tamas/dev/igraph/igraph/src/io/lgl-parser.y"
+
 
 
 int igraph_lgl_yyerror(YYLTYPE* locp, igraph_i_lgl_parsedata_t *context, 
